function LogLike = LogLikeGivenCC(D,CC,option)
% function LogLike = LogLikeGivenCC(D,CC,option)

% determine size of arrays
[M,K] = size(CC);
[N,M] = size(D);

% Normalize column vectors in CC
CC = normalize(CC);

% Check for special clustering of 1st class
if option == 1
  CC(:,1) = 0*CC(:,1);
else
  option = 0;
end

% Compute norms of data vectors
datanorm = sum(D.*D,2);

% Compute norm of data minus projection
tmp = D*CC;
projnorm = repmat(datanorm,[1,K]) - tmp.*tmp;

% Clip norm to 0 due to floating point roundoff errors
if min(min(projnorm))<0
  disp(sprintf('Warning: computed negative projected norm of %e',...
                min(min(projnorm)) ));
end
projnorm = max(projnorm,0);

% Use i.i.d Gaussian assumption to compute Log Likelihood
if option ==1 % assume first class is zero mean

  LogLike = -0.5*projnorm - 0.5*(M-1)*log(2*pi);
  LogLike(:,1) = LogLike(:,1) - 0.5*log(2*pi); 

  LogLike = LogLike + repmat(OrderID1LogLike(K,M),[N,1]); 

else % assume all classes are the same

  LogLike = -0.5*projnorm - 0.5*(M-1)*log(2*pi);

end

